@@ -50,13 +50,13 @@ from django.forms import fields
 from django.template.defaultfilters import urlencode
 from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
+from dj.choices import Language
 
 try:
     from django.utils.timezone import now
 except ImportError:
     now = datetime.now
 
-from lck.django.choices import Language
 from lck.django.common import monkeys, nested_commit_on_success
 
 
@@ -414,14 +414,14 @@ class Localized(db.Model):
     is settings.LANGUAGE_CODE."""
     language = db.PositiveIntegerField(verbose_name=_("language"),
         choices=Language(filter=set([lang[0] for lang in settings.LANGUAGES])),
-            default=Language.IDFromName(settings.LANGUAGE_CODE))
+            default=Language.id_from_name(settings.LANGUAGE_CODE))
 
     class Meta:
         abstract = True
 
     @property
     def lang(self):
-        l = Language.FromID(self.language)
+        l = Language.from_id(self.language)
         return (l.name, l.desc)
 
 
@@ -621,50 +621,3 @@ class MACAddressField(db.Field):
         if self.default is not db.NOT_PROVIDED:
             kwargs['default'] = repr(self.default)
         return ('lck.django.common.models.MACAddressField', [], kwargs)
-
-
-# For now this needs to be at the end of the file.
-# FIXME: move it where it's supposed to be.
-
-import os
-from time import sleep
-from threading import Thread
-
-class MassMailer(Thread):
-    """
-    A thread that can be used to mail the specified profiles with a certain
-    message. After every message it waits a specified time (by default
-    a second).
-    """
-    def __init__ (self, profiles, subject, content, inverval=1.0, force=False):
-        """Creates the thread.
-
-        :param profiles: a sequence of profiles that are to be mailed
-
-        :param subject: the subject of the message to be sent
-
-        :param content: the actual content to be sent
-
-        :param interval: number of seconds to wait after sending every message
-
-        :param force: if ``True``, privacy settings of the users are
-                      disregarded
-        """
-
-        Thread.__init__(self)
-        self.profiles = profiles
-        self.subject = subject
-        self.content = content
-        self.interval = interval
-        self.force = force
-
-    def run(self):
-        print("Mailer subprocess started (%d)." % os.getpid())
-        for profile in self.profiles:
-            mail = profile.user.email
-            # FIXME: check privacy
-            send_mail(self.subject, self.content, None, [mail])
-            print("Mailer subprocess (%d): sent mail to %s." % (os.getpid(), mail))
-            sleep(self.interval)
-
-# NO CODE BEYOND THIS POINT
